import React from "react";
import PropTypes from "prop-types";
import { useDispatch } from "react-redux";

import { prettyEpisodeName } from "../../../utils";
import { removeTorrent } from "../../../actions/torrents";

import { Progress } from "./progress";

export const Torrent = ({ torrent }) => {
  const dispatch = useDispatch();

  const torrentTitle = (torrent) => {
    switch (torrent.type) {
      case "movie":
        return torrent.video ? torrent.video.title : torrent.status.name;
      case "episode":
        return torrent.video
          ? prettyEpisodeName(
              torrent.video.show_title,
              torrent.video.season,
              torrent.video.episode
            )
          : torrent.status.name;
      default:
        return torrent.status.name;
    }
  };

  return (
    <div className="card w-100 mb-3">
      <h5 className="card-header">
        <span className="text text-break">{torrentTitle(torrent)}</span>
        <span
          className="fa fa-trash clickable pull-right"
          onClick={() => dispatch(removeTorrent(torrent.status.id))}
        ></span>
      </h5>
      <Progress torrent={torrent} />
    </div>
  );
};
Torrent.propTypes = {
  torrent: PropTypes.object.isRequired,
};
